#ifndef NT2_INCLUDE_FUNCTIONS_ONEPLUS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ONEPLUS_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/oneplus.hpp>

#endif
